const Movie = require('../models/movie.js')
const express = require('express')
const router = express.Router()

// GET all movies
router.route('/movies').get(function (req, res) {
  Movie.find(function (err, movies) {
    if (err) {
      return res.send(err)
    }
    res.json(movies)
  })
})

// POST new movie
router.route('/movies').post(function (req, res) {
  const movie = new Movie(req.body)

  movie.save(function (err) {
    if (err) {
      return res.send(err)
    }
    res.send({ message: 'Movie added.' })
  })
})

// PUT update movie
router.route('/movies/:id').put(function (req, res) {
  Movie.findOne({ _id: req.params.id }, function (err, movie) {
    if (err) {
      return res.send(err)
    }

    for (prop in req.body) {
      movie[prop] = req.body[prop]
    }

    movie.save(function (req, res) {
      if (err) {
        return res.send(err)
      }
      res.json({ message: 'Movie updated.' })
    })
  })
})

// GET one movie
router.route('/movies/:id').get(function (req, res) {
  Movie.findOne({ _id: req.params.id }, function (err, movie) {
    if (err) {
      return res.send(err)
    }
    res.json(movie)
  })
})

// DELETE one
router.route('/movies/:id').delete(function (req, res) {
  Movie.remove({ _id: req.params.id }, function (err, movie) {
    if (err) {
      return res.send(err)
    }
    res.json({ message: 'Movie deleted.' })
  })
})

module.exports = router
