const data = {}
let idx
for (idx = 0; idx < 10; idx += 1) {
  data[idx] = `data ${idx}`
}

export default function request (url, options) {
  return new Promise((resolve, reject) => {
    // Parse the url.
    const parsed = url.match(/^http:\/\/localhost\/db(\/\w+)?(\/\w+)?\/?$/)
    if (!parsed) {
      reject(Error('url could not be parsed.'))
    }

    // extract the params.
    let [ urlString, module, id ] = parsed
    if (module) {
      module = module.substring(1)
    }
    if (id) {
      id = id.substring(1)
    }

    // check the method
    if (typeof options.method === 'undefined' || !options.method.match(/GET|PUT|POST|DELETE/)) {
      reject(Error('method not supported.'))
    }
    // http://www.restapitutorial.com/lessons/httpmethods.html
    switch (options.method) {
      case 'POST':
        if (id) {
          if (typeof data[id] !== 'undefined') {
            reject(Error('409: conflict'))
          } else {
            reject(Error('404: not found'))
          }
        } else {
          resolve({ message: `201: created. ${urlString}/2` })
        }
        break
      case 'GET':
        if (id) {
          if (typeof data[id] !== 'undefined') {
            resolve(data[id])
          } else {
            reject(Error('404: not found'))
          }
        } else {
          resolve(data)
        }
        break
      case 'PUT':
        if (id) {
          if (typeof data[id] !== 'undefined') {
            resolve({ message: '200: ok' })
          } else {
            reject(Error('404: not found'))
          }
        } else {
          reject(Error('404: not found'))
        }
        break
      case 'DELETE':
        if (id) {
          if (typeof data[id] !== 'undefined') {
            resolve({ message: '200: ok' })
          } else {
            reject(Error('404: not found'))
          }
        } else {
          reject(Error('404: not found'))
        }
        break
    }
  })
}
