/** The basic CRUD API supports the following functionality:
  * /api[/module][/id|/offset[/limit]]
  *
  * Other functions
  */

import request from 'request-promise'
export function crudHttpApi (action, options) {
  const { uri } = options
  // determine the operation
  const [ name, actionType ] = action.type.split('/')
  const requestOptions = {
    uri: `${uri}/${name}`,
    method: null,
    body: null
  }
  switch (actionType) {
    case 'READ_REQUEST':
      options.uri = `${uri}/${action.id}`
      options.method = 'GET'
      break
    case 'CREATE_REQUEST':
      options.method = 'POST'
      options.body = action.data
      break
    case 'UPDATE_REQUEST':
      options.uri = `${uri}/${action.id}`
      options.method = 'PUT'
      break
    case 'DELETE_REQUEST':
      options.uri = `${uri}/${action.id}`
      options.method = 'DELETE'
      break
  }
  // Request from the request-promise library already returns a promise.
  return request(requestOptions)
}
