import {actionCreators, state, reducer} from './state.js'
console.log(actionCreators)

describe('actions', () => {
  describe('primary actions', () => {
    it('creates primary actions', () => {
      const id = 'primary-1'
      const data = {id: 'primary-1', name: 'some name', secondary: []}
      expect(actionCreators.createPrimary(id, data)).toEqual({type: 'demo_module/CREATE_PRIMARY', id, data})
      expect(actionCreators.updatePrimary(id, data)).toEqual({type: 'demo_module/UPDATE_PRIMARY', id, data})
      expect(actionCreators.removePrimary(id, data)).toEqual({type: 'demo_module/REMOVE_PRIMARY', id, data})
    })
  })
  describe('secondary actions', () => {
    it('creates secondary actions', () => {
      const primaryId = 'primary-1'
      const id = 'secondary-1'
      const data = {id: 'secondary-1', name: 'some name'}
      expect(actionCreators.createSecondary(primaryId, id, data)).toEqual({type: 'demo_module/CREATE_SECONDARY', primaryId, id, data})
      expect(actionCreators.updateSecondary(primaryId, id, data)).toEqual({type: 'demo_module/UPDATE_SECONDARY', primaryId, id, data})
      expect(actionCreators.removeSecondary(primaryId, id, data)).toEqual({type: 'demo_module/REMOVE_SECONDARY', primaryId, id, data})
    })
  })
  describe('additional actions', () => {
    it('creates additional actions', () => {
      const data = {id: 'primary-1', name: 'some name', secondary: []}
      expect(actionCreators.loadSamples()).toEqual({type: 'demo_module/LOAD_SAMPLES'})
    })
  })
})
describe('state', () => {
  it('default state is empty array', () => {
    const defaultState = []
    expect(state).toEqual([])
  })
})

describe('reducer', () => {
  const initialSecondary = { id: 'secondary-1', name: 'Secondary 1' }
  const otherSecondary = { id: 'secondary-2', name: 'Secondary 2' }
  const initialPrimary = { id: 'primary-1', name: 'Primary 1', active: true, secondary: [initialSecondary]}
  const initialState = [initialPrimary]
  const otherPrimary = { id: 'primary-2', name: 'Primary 2', active: false, secondary: [otherSecondary]}

  describe('initialization', () => {
    it('returns the initial state', () => {
      expect(reducer(undefined, {})).toEqual([])
    })
  })
  describe('primary reduction', () => {
    it('handles CREATE_PRIMARY', () => {
      expect(reducer(initialState, {type: 'demo_module/CREATE_PRIMARY', id: otherPrimary.id, data: otherPrimary})).toEqual([initialPrimary, otherPrimary])
    })
    it('handles UPDATE_PRIMARY', () => {
      expect(reducer(initialState, {type: 'demo_module/UPDATE_PRIMARY', id: initialPrimary.id, data: otherPrimary})).toEqual([otherPrimary])
    })
    it('handles REMOVE_PRIMARY', () => {
      expect(reducer(initialState, {type: 'demo_module/REMOVE_PRIMARY', id: initialPrimary.id, data: initialPrimary})).toEqual([])
    })
  })
  describe('secondary reduction', () => {
    it('handles CREATE_SECONDARY', () => {
      expect(reducer(initialState, {type: 'demo_module/CREATE_SECONDARY', primaryid: initialPrimary.id, id: otherSecondary.id, data: otherSecondary})).toEqual([{...initialPrimary, secondary: [initialSecondary, otherSecondary]}])
    })
    it('handles UPDATE_SECONDARY', () => {
      expect(reducer(initialState, {type: 'demo_module/UPDATE_SECONDARY', primaryId: initialPrimary.id, id: initialSecondary.id, data: otherSecondary})).toEqual([{...initialPrimary, secondary: [otherSecondary]}])
    })
    it('handles REMOVE_SECONDARY', () => {
      expect(reducer(initialState, {type: 'demo_module/REMOVE_SECONDARY', primaryId: initialPrimary.id, id: initialSecondary.id, data: initialSecondary})).toEqual([{...initialPrimary, secondary: []}])
    })
  })
})
